==> inkspot-0.0.1-20140206.000109-11.jar: inkspot/color_chart/x11.clj <==
(ns inkspot.color-chart.x11)

; Derived from http://www.mcfedries.com/books/cightml/x11color.htm

(def swatch
  (array-map
    :lightpink "#FFB6C1"
    :pink "#FFC0CB"
    :crimson "#DC143C"
    :lavenderblush "#FFF0F5"
    :palevioletred "#DB7093"
    :hotpink "#FF69B4"
    :deeppink "#FF1493"
    :mediumvioletred "#C71585"
    :orchid "#DA70D6"
    :thistle "#D8BFD8"
    :plum "#DDA0DD"
    :violet "#EE82EE"
    :magenta "#FF00FF"
    :fuchsia "#FF00FF"
    :darkmagenta "#8B008B"
    :purple "#800080"
    :mediumorchid "#BA55D3"
    :darkviolet "#9400D3"
    :darkorchid "#9932CC"
    :indigo "#4B0082"
    :blueviolet "#8A2BE2"
    :mediumpurple "#9370DB"
    :mediumslateblue "#7B68EE"
    :slateblue "#6A5ACD"
    :darkslateblue "#483D8B"
    :lavender "#E6E6FA"
    :ghostwhite "#F8F8FF"
    :blue "#0000FF"
    :mediumblue "#0000CD"
    :midnightblue "#191970"
    :darkblue "#00008B"
    :navy "#000080"
    :royalblue "#4169E1"
    :cornflowerblue "#6495ED"
    :lightsteelblue "#B0C4DE"
    :lightslategray "#778899"
    :slategray "#708090"
    :dodgerblue "#1E90FF"
    :aliceblue "#F0F8FF"
    :steelblue "#4682B4"
    :lightskyblue "#87CEFA"
    :skyblue "#87CEEB"
    :deepskyblue "#00BFFF"
    :lightblue "#ADD8E6"
    :powderblue "#B0E0E6"
    :cadetblue "#5F9EA0"
    :azure "#F0FFFF"
    :lightcyan "#E0FFFF"
    :paleturquoise "#AFEEEE"
    :cyan "#00FFFF"
    :aqua "#00FFFF"
    :darkturquoise "#00CED1"
    :darkslategray "#2F4F4F"
    :darkcyan "#008B8B"
    :teal "#008080"
    :mediumturquoise "#48D1CC"
    :lightseagreen "#20B2AA"
    :turquoise "#40E0D0"
    :aquamarine "#7FFFD4"
    :mediumaquamarine "#66CDAA"
    :mediumspringgreen "#00FA9A"
    :mintcream "#F5FFFA"
    :springgreen "#00FF7F"
    :mediumseagreen "#3CB371"
    :seagreen "#2E8B57"
    :honeydew "#F0FFF0"
    :lightgreen "#90EE90"
    :palegreen "#98FB98"
    :darkseagreen "#8FBC8F"
    :limegreen "#32CD32"
    :lime "#00FF00"
    :forestgreen "#228B22"
    :green "#008000"
    :darkgreen "#006400"
    :chartreuse "#7FFF00"
    :lawngreen "#7CFC00"
    :greenyellow "#ADFF2F"
    :darkolivegreen "#556B2F"
    :yellowgreen "#9ACD32"
    :olivedrab "#6B8E23"
    :beige "#F5F5DC"
    :lightgoldenrodyellow "#FAFAD2"
    :ivory "#FFFFF0"
    :lightyellow "#FFFFE0"
    :yellow "#FFFF00"
    :olive "#808000"
    :darkkhaki "#BDB76B"
    :lemonchiffon "#FFFACD"
    :palegoldenrod "#EEE8AA"
    :khaki "#F0E68C"
    :gold "#FFD700"
    :cornsilk "#FFF8DC"
    :goldenrod "#DAA520"
    :darkgoldenrod "#B8860B"
    :floralwhite "#FFFAF0"
    :oldlace "#FDF5E6"
    :wheat "#F5DEB3"
    :moccasin "#FFE4B5"
    :orange "#FFA500"
    :papayawhip "#FFEFD5"
    :blanchedalmond "#FFEBCD"
    :navajowhite "#FFDEAD"
    :antiquewhite "#FAEBD7"
    :tan "#D2B48C"
    :burlywood "#DEB887"
    :bisque "#FFE4C4"
    :darkorange "#FF8C00"
    :linen "#FAF0E6"
    :peru "#CD853F"
    :peachpuff "#FFDAB9"
    :sandybrown "#F4A460"
    :chocolate "#D2691E"
    :saddlebrown "#8B4513"
    :seashell "#FFF5EE"
    :sienna "#A0522D"
    :lightsalmon "#FFA07A"
    :coral "#FF7F50"
    :orangered "#FF4500"
    :darksalmon "#E9967A"
    :tomato "#FF6347"
    :mistyrose "#FFE4E1"
    :salmon "#FA8072"
    :snow "#FFFAFA"
    :lightcoral "#F08080"
    :rosybrown "#BC8F8F"
    :indianred "#CD5C5C"
    :red "#FF0000"
    :brown "#A52A2A"
    :firebrick "#B22222"
    :darkred "#8B0000"
    :maroon "#800000"
    :white "#FFFFFF"
    :whitesmoke "#F5F5F5"
    :gainsboro "#DCDCDC"
    :lightgrey "#D3D3D3"
    :silver "#C0C0C0"
    :darkgray "#A9A9A9"
    :gray "#808080"
    :dimgray "#696969"
    :black "#000000"))

==> inkspot-0.0.1-20141206.002631-22.jar: inkspot/color_chart/x11.clj <==
(ns inkspot.color-chart.x11
  "Derived from http://www.mcfedries.com/books/cightml/x11color.htm")

(def swatch
  (array-map
    :lightpink "#FFB6C1"
    :pink "#FFC0CB"
    :crimson "#DC143C"
    :lavenderblush "#FFF0F5"
    :palevioletred "#DB7093"
    :hotpink "#FF69B4"
    :deeppink "#FF1493"
    :mediumvioletred "#C71585"
    :orchid "#DA70D6"
    :thistle "#D8BFD8"
    :plum "#DDA0DD"
    :violet "#EE82EE"
    :magenta "#FF00FF"
    :fuchsia "#FF00FF"
    :darkmagenta "#8B008B"
    :purple "#800080"
    :mediumorchid "#BA55D3"
    :darkviolet "#9400D3"
    :darkorchid "#9932CC"
    :indigo "#4B0082"
    :blueviolet "#8A2BE2"
    :mediumpurple "#9370DB"
    :mediumslateblue "#7B68EE"
    :slateblue "#6A5ACD"
    :darkslateblue "#483D8B"
    :lavender "#E6E6FA"
    :ghostwhite "#F8F8FF"
    :blue "#0000FF"
    :mediumblue "#0000CD"
    :midnightblue "#191970"
    :darkblue "#00008B"
    :navy "#000080"
    :royalblue "#4169E1"
    :cornflowerblue "#6495ED"
    :lightsteelblue "#B0C4DE"
    :lightslategray "#778899"
    :slategray "#708090"
    :dodgerblue "#1E90FF"
    :aliceblue "#F0F8FF"
    :steelblue "#4682B4"
    :lightskyblue "#87CEFA"
    :skyblue "#87CEEB"
    :deepskyblue "#00BFFF"
    :lightblue "#ADD8E6"
    :powderblue "#B0E0E6"
    :cadetblue "#5F9EA0"
    :azure "#F0FFFF"
    :lightcyan "#E0FFFF"
    :paleturquoise "#AFEEEE"
    :cyan "#00FFFF"
    :aqua "#00FFFF"
    :darkturquoise "#00CED1"
    :darkslategray "#2F4F4F"
    :darkcyan "#008B8B"
    :teal "#008080"
    :mediumturquoise "#48D1CC"
    :lightseagreen "#20B2AA"
    :turquoise "#40E0D0"
    :aquamarine "#7FFFD4"
    :mediumaquamarine "#66CDAA"
    :mediumspringgreen "#00FA9A"
    :mintcream "#F5FFFA"
    :springgreen "#00FF7F"
    :mediumseagreen "#3CB371"
    :seagreen "#2E8B57"
    :honeydew "#F0FFF0"
    :lightgreen "#90EE90"
    :palegreen "#98FB98"
    :darkseagreen "#8FBC8F"
    :limegreen "#32CD32"
    :lime "#00FF00"
    :forestgreen "#228B22"
    :green "#008000"
    :darkgreen "#006400"
    :chartreuse "#7FFF00"
    :lawngreen "#7CFC00"
    :greenyellow "#ADFF2F"
    :darkolivegreen "#556B2F"
    :yellowgreen "#9ACD32"
    :olivedrab "#6B8E23"
    :beige "#F5F5DC"
    :lightgoldenrodyellow "#FAFAD2"
    :ivory "#FFFFF0"
    :lightyellow "#FFFFE0"
    :yellow "#FFFF00"
    :olive "#808000"
    :darkkhaki "#BDB76B"
    :lemonchiffon "#FFFACD"
    :palegoldenrod "#EEE8AA"
    :khaki "#F0E68C"
    :gold "#FFD700"
    :cornsilk "#FFF8DC"
    :goldenrod "#DAA520"
    :darkgoldenrod "#B8860B"
    :floralwhite "#FFFAF0"
    :oldlace "#FDF5E6"
    :wheat "#F5DEB3"
    :moccasin "#FFE4B5"
    :orange "#FFA500"
    :papayawhip "#FFEFD5"
    :blanchedalmond "#FFEBCD"
    :navajowhite "#FFDEAD"
    :antiquewhite "#FAEBD7"
    :tan "#D2B48C"
    :burlywood "#DEB887"
    :bisque "#FFE4C4"
    :darkorange "#FF8C00"
    :linen "#FAF0E6"
    :peru "#CD853F"
    :peachpuff "#FFDAB9"
    :sandybrown "#F4A460"
    :chocolate "#D2691E"
    :saddlebrown "#8B4513"
    :seashell "#FFF5EE"
    :sienna "#A0522D"
    :lightsalmon "#FFA07A"
    :coral "#FF7F50"
    :orangered "#FF4500"
    :darksalmon "#E9967A"
    :tomato "#FF6347"
    :mistyrose "#FFE4E1"
    :salmon "#FA8072"
    :snow "#FFFAFA"
    :lightcoral "#F08080"
    :rosybrown "#BC8F8F"
    :indianred "#CD5C5C"
    :red "#FF0000"
    :brown "#A52A2A"
    :firebrick "#B22222"
    :darkred "#8B0000"
    :maroon "#800000"
    :white "#FFFFFF"
    :whitesmoke "#F5F5F5"
    :gainsboro "#DCDCDC"
    :lightgrey "#D3D3D3"
    :silver "#C0C0C0"
    :darkgray "#A9A9A9"
    :gray "#808080"
    :dimgray "#696969"
    :black "#000000"))
